==> db4o-5.0-mono.tar.gz: db4o-5.0/src/core/src/core/com/db4o/nativequery/expr/cmp/ArithmeticExpression.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
namespace com.db4o.nativequery.expr.cmp
{
	public class ArithmeticExpression : com.db4o.nativequery.expr.cmp.ComparisonOperand
	{
		private com.db4o.nativequery.expr.cmp.ArithmeticOperator _op;

		private com.db4o.nativequery.expr.cmp.ComparisonOperand _left;

		private com.db4o.nativequery.expr.cmp.ComparisonOperand _right;

		public ArithmeticExpression(com.db4o.nativequery.expr.cmp.ComparisonOperand left, 
			com.db4o.nativequery.expr.cmp.ComparisonOperand right, com.db4o.nativequery.expr.cmp.ArithmeticOperator
			 op)
		{
			this._op = op;
			this._left = left;
			this._right = right;
		}

		public virtual com.db4o.nativequery.expr.cmp.ComparisonOperand left()
		{
			return _left;
		}

		public virtual com.db4o.nativequery.expr.cmp.ComparisonOperand right()
		{
			return _right;
		}

		public virtual com.db4o.nativequery.expr.cmp.ArithmeticOperator op()
		{
			return _op;
		}

		public override string ToString()
		{
			return "(" + _left + _op + _right + ")";
		}

		public override bool Equals(object obj)
		{
			if (this == obj)
			{
				return true;
			}
			if (obj == null || j4o.lang.Class.getClassForObject(obj) != j4o.lang.Class.getClassForObject
				(this))
			{
				return false;
			}
			com.db4o.nativequery.expr.cmp.ArithmeticExpression casted = (com.db4o.nativequery.expr.cmp.ArithmeticExpression
				)obj;
			return _left.Equals(casted._left) && _right.Equals(casted._right) && _op.Equals(casted
				._op);
		}

		public override int GetHashCode()
		{
			int hc = _left.GetHashCode();
			hc *= 29 + _right.GetHashCode();
			hc *= 29 + _op.GetHashCode();
			return hc;
		}

		public virtual void accept(com.db4o.nativequery.expr.cmp.ComparisonOperandVisitor
			 visitor)
		{
			visitor.visit(this);
		}
	}
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/core/src/core/com/db4o/nativequery/expr/cmp/ArithmeticExpression.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
namespace com.db4o.nativequery.expr.cmp
{
	public class ArithmeticExpression : com.db4o.nativequery.expr.cmp.ComparisonOperand
	{
		private com.db4o.nativequery.expr.cmp.ArithmeticOperator _op;

		private com.db4o.nativequery.expr.cmp.ComparisonOperand _left;

		private com.db4o.nativequery.expr.cmp.ComparisonOperand _right;

		public ArithmeticExpression(com.db4o.nativequery.expr.cmp.ComparisonOperand left, 
			com.db4o.nativequery.expr.cmp.ComparisonOperand right, com.db4o.nativequery.expr.cmp.ArithmeticOperator
			 op)
		{
			this._op = op;
			this._left = left;
			this._right = right;
		}

		public virtual com.db4o.nativequery.expr.cmp.ComparisonOperand Left()
		{
			return _left;
		}

		public virtual com.db4o.nativequery.expr.cmp.ComparisonOperand Right()
		{
			return _right;
		}

		public virtual com.db4o.nativequery.expr.cmp.ArithmeticOperator Op()
		{
			return _op;
		}

		public override string ToString()
		{
			return "(" + _left + _op + _right + ")";
		}

		public override bool Equals(object obj)
		{
			if (this == obj)
			{
				return true;
			}
			if (obj == null || j4o.lang.Class.GetClassForObject(obj) != j4o.lang.Class.GetClassForObject
				(this))
			{
				return false;
			}
			com.db4o.nativequery.expr.cmp.ArithmeticExpression casted = (com.db4o.nativequery.expr.cmp.ArithmeticExpression
				)obj;
			return _left.Equals(casted._left) && _right.Equals(casted._right) && _op.Equals(casted
				._op);
		}

		public override int GetHashCode()
		{
			int hc = _left.GetHashCode();
			hc *= 29 + _right.GetHashCode();
			hc *= 29 + _op.GetHashCode();
			return hc;
		}

		public virtual void Accept(com.db4o.nativequery.expr.cmp.ComparisonOperandVisitor
			 visitor)
		{
			visitor.Visit(this);
		}
	}
}
